from .config import _which_ffprobe

import os
import re
import subprocess
import json
import ntpath
import configparser

def _ffprobe(file_path, pformat='ini', pstdout=subprocess.PIPE, psubprocess='call'):
    if psubprocess == 'call':
        return subprocess.call([_which_ffprobe(), '-v', 'quiet', '-print_format', pformat, '-show_format', '-show_streams', file_path], stdout=pstdout)
    elif psubprocess == 'Popen':
        return subprocess.Popen([_which_ffprobe(), '-v', 'quiet', '-print_format', pformat, '-show_format', '-show_streams', file_path], stdout=pstdout)

def _get_data(request_info='all'):
    dict = {}
    tmp_dict = {}
    config_object = configparser.ConfigParser()
    config_object.read("tempdata.ini")
    config_sections = config_object.sections()

    if request_info != 'all':
        for section in config_sections:
            for option in config_object.options(section):
                for item in request_info:
                    if option == item:
                        default = config_object[section]
                        dict[section + '.' + option] = default[item]
    else:
        for section in config_sections:
            for option in config_object.options(section):
                default = config_object[section]
                tmp_dict[option] = default[option]

            dict[section] = tmp_dict
            tmp_dict = {}

    return dict

class Worker():
    def __init__(
        self,
        input_file,
        request_data,
        output_format,
        save_path,
    ):
        self.input_file = input_file
        self.request_data = request_data
        self.output_format = output_format
        self.save_path = save_path

    def _application(self):
        if self.request_data == 'False' and self.output_format == 'False' and self.save_path == 'False':
            proc = _ffprobe(self.input_file, psubprocess='Popen')
            output = str(proc.stdout.read())
            list1 = output.split("\\n")
            for i in list1:
                print(i)

        elif self.output_format != 'False' and self.save_path != 'False' and self.request_data == 'False':
            if self.output_format == 'json':
                f = open(os.path.join(os.path.dirname(self.input_file), (ntpath.basename(self.input_file[:-4]) + ".json")), "w")
                _ffprobe(self.input_file, pformat='json', pstdout=f)
                f.close

            elif self.output_format == 'ini':
                f = open(os.path.join(os.path.dirname(self.input_file), (ntpath.basename(self.input_file[:-4]) + ".ini")), "w")
                _ffprobe(self.input_file, pformat='ini', pstdout=f)
                f.close

        elif self.request_data != 'False':
            f = open("tempdata.ini", "w")
            _ffprobe(self.input_file, pformat='ini', pstdout=f)
            f.close
            return_data = _get_data(re.split("; |, |[\\s,]+|\n", self.request_data))
            for section in return_data:
                print("{:<20} :".format(section), return_data[section])

def mediainfo(file_path):
    f = open("tempdata.ini", "w")
    _ffprobe(file_path, pformat='ini', pstdout=f)
    f.close

    return _get_data()


from .config    import _which_ffprobe, _extract_dependencies
from .run       import Worker, _ffprobe, _get_data, mediainfo
from .utils     import _check_os, _packagePath, _extract_zip, _set_executable
from .version   import __version__



from .run       import Worker
from .version   import __version__
import argparse

def main():
    parser = argparse.ArgumentParser(
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
        description="infomedia {}".format(__version__)
    )
    parser.add_argument("input", help="File path")

    parser.add_argument(
        "-i",
        "--info",
        type=str,
        default="False",
        help="Get information about",
    )

    parser.add_argument(
        "-s",
        "--save-path",
        type=str,
        default="False",
        help="A file path to save the data file",
    )

    parser.add_argument(
        "-of",
        "--output-format",
        type=str,
        default="False",
        choices=["json", "ini"],
        help="Data file format",
    )

    parser.add_argument(
        "-v",
        "--version",
        action='version',
        version=__version__,
        help="infomedia version",
    )

    cli_args = parser.parse_args()

    worker = Worker(
        cli_args.input,
        cli_args.info,
        cli_args.output_format,
        cli_args.save_path
    )

    worker._application()

if __name__ == '__main__':
    main()


import os
import sys
import pathlib
import zipfile

import infomedia as _

def _check_os():
    if sys.platform == 'win32':
        return 'win32'
    elif sys.platform == 'linux':
        return 'linux'
    elif sys.platform == 'darwin':
        return 'darwin'

def _packagePath():
    return _.__path__[0]

def _extract_zip(file_path):
    with zipfile.ZipFile(file_path, 'r') as zipObj:
        zipObj.extractall(os.path.dirname(file_path))

def _set_executable(a):
    if _check_os() != 'win32':
        os.chmod(a, 0o755)



from .utils     import _check_os, _set_executable, _packagePath, _extract_zip

import os

def _which_ffprobe():
    if not os.path.isfile(os.path.join(_packagePath(), 'dependencies', 'ffprobe_linux')):
        _extract_dependencies()

    if _check_os() == 'linux':
        ffprobe_path = os.path.join(_packagePath(), 'dependencies', 'ffprobe_linux')
    elif _check_os() == 'win32':
        ffprobe_path = os.path.join(_packagePath(), 'dependencies', 'ffprobe_win.exe')
    elif _check_os() == 'darwin':
        ffprobe_path = os.path.join(_packagePath(), 'dependencies', 'ffprobe_darwin')
    _set_executable(ffprobe_path)

    return ffprobe_path

def _extract_dependencies():
    _extract_zip(os.path.join(_packagePath(), 'dependencies', 'ffprobe.zip'))


import  pathlib

from    setuptools      import setup, find_packages

exec(open("infomedia/version.py").read())

here = pathlib.Path(__file__).parent
with open('README.rst') as readme_file:
    long_description = readme_file.read()

setup(
    name="infomedia",
    version=__version__,
    description="This is a Python application that can be used to retrieve media file information such as duration, frame rate, bit rate, etc..",
    long_description=long_description,
    author="tharindu.dev",
    author_email="tharindu.nm@yahoo.com",
    url="https://github.com/truethari/infomedia",
    keywords="video ffmpeg ffprobe",
    project_urls={
        "Source": 'https://github.com/truethari/infomedia/',
        "Bug Tracker": "https://github.com/truethari/infomedia/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
    ],
    packages=['infomedia'],
    include_package_data=True,
    package_data = {'' : ['dependencies/*.zip']},
    entry_points={
        "console_scripts": [
            "infomedia=infomedia.__main__:main",
        ]
    },
)
